[Pkg-puppet-devel] [SCM] Puppet packaging for Debian branch, upstream, updated. 0.25.5-639-g8f94f35

test branch puppet-dev at googlegroups.com
Wed Jul 14 10:34:25 UTC 2010


The following commit has been merged in the upstream branch:
commit 86bd83877017f91922c17e311058d1cc8fbd55f8
Author: David Schmitt <david at dasz.at>
Date:   Fri May 21 15:37:51 2010 +0200

    Move syslog into a feature

diff --git a/lib/puppet/util/log.rb b/lib/puppet/util/log.rb
index c64cbe5..ba23e12 100644
--- a/lib/puppet/util/log.rb
+++ b/lib/puppet/util/log.rb
@@ -1,4 +1,3 @@
-require 'syslog'
 require 'puppet/util/tagging'
 require 'puppet/util/classgen'
 

diff --git a/lib/puppet/feature/base.rb b/lib/puppet/feature/base.rb
index a8fba34..8a21fd3 100644
--- a/lib/puppet/feature/base.rb
+++ b/lib/puppet/feature/base.rb
@@ -32,10 +32,13 @@ Puppet.features.add(:rrd, :libs => ["RRDtool"])
 # We have OpenSSL
 Puppet.features.add(:openssl, :libs => ["openssl"])
 
-# We can use POSIX user functions? The require returns false on Windows
+# We have a syslog implementation
+Puppet.features.add(:syslog, :libs => ["syslog"])
+
+# We can use POSIX user functions
 Puppet.features.add(:posix) do
     require 'etc'
-    Etc.getpwuid(0) != nil
+    Etc.getpwuid(0) != nil && Puppet.features.syslog?
 end
 
 # We can use Win32 functions
-- 
Puppet packaging for Debian



More information about the Pkg-puppet-devel mailing list